WxTextTileStyle class

The style to be applied to WxTextTile widget

Mixed-in types
Annotations

Constructors

WxTextTileStyle({double? spacing, EdgeInsetsGeometry? margin, TextAlign? align, Color? color, TextOverflow? overflow, bool? softWrap, TextWidthBasis? widthBasis, TextStyle? titleStyle, Color? titleColor, FontWeight? titleWeight, double? titleSize, int? titleMaxLines, TextStyle? subtitleStyle, Color? subtitleColor, FontWeight? subtitleWeight, double? subtitleSize, int? subtitleMaxLines})
Create a raw WxTextTileStyle
const
WxTextTileStyle.defaults()
Create a WxTextTileStyle with default value
const
WxTextTileStyle.from(WxTextTileStyle? other)
Create a WxTextTileStyle from another style

Properties

align → TextAlign?
How the title and subtitle should be placed along the cross axis.
final
color → Color?
The text color to be applied to title and subtitle.
final
hashCode → int
The hash code for this object.
no setteroverride
margin → EdgeInsetsGeometry?
Outer space around the widget.
final
overflow → TextOverflow?
The text overflow to be applied to title and subtitle.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softWrap → bool?
The text softWrap to be applied to title and subtitle.
final
spacing → double?
The gap between the title and the subtitle widgets.
final
subtitleColor → Color?
The text color to be applied to subtitle.
final
subtitleMaxLines → int?
The text max lines to be applied to subtitle.
final
subtitleSize → double?
The font size to be applied to subtitle.
final
subtitleStyle → TextStyle?
The text style to be applied to subtitle.
final
subtitleWeight → FontWeight?
The font weight to be applied to subtitle.
final
titleColor → Color?
The text color to be applied to title.
final
titleMaxLines → int?
The text max lines to be applied to title.
final
titleSize → double?
The font size to be applied to title.
final
titleStyle → TextStyle?
The text style to be applied to title.
final
titleWeight → FontWeight?
The font weight to be applied to title.
final
widthBasis → TextWidthBasis?
The text width basis to be applied to title and subtitle.
final

Methods

copyWith({double? spacing, EdgeInsetsGeometry? margin, TextAlign? align, Color? color, TextOverflow? overflow, bool? softWrap, TextWidthBasis? widthBasis, TextStyle? titleStyle, Color? titleColor, FontWeight? titleWeight, double? titleSize, int? titleMaxLines, TextStyle? subtitleStyle, Color? subtitleColor, FontWeight? subtitleWeight, double? subtitleSize, int? subtitleMaxLines}) → WxTextTileStyle
Creates a copy of this WxTextTileStyle but with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(WxTextTileStyle? other) → WxTextTileStyle
Creates a copy of this WxTextTileStyle but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

lerp(WxTextTileStyle? a, WxTextTileStyle? b, double t) → WxTextTileStyle?
Linearly interpolate between two WxTextTileStyle objects.